@@ -1,4 +1,4 @@
-#' Radviz Object Summary, head, print, dim Methods
+#' Radviz Object Summary, head, print, dim and springs Methods
 #' 
 #' Provides a summary for Radviz objects
 #' 
@@ -7,6 +7,8 @@
 #' @param n the number of lines from each slots in the Radviz object to display (defaults to 6)
 #' @param ...	further arguments to be passed to or from other methods (not implemented)
 #' 
+#' @details \code{dim} returns the number of points and the number of dimensions used for the projection
+#' 
 #' @example examples/example-do.radviz.R
 #' @examples
 #' 
@@ -19,12 +21,12 @@
 #' @importFrom utils head
 #' @export
 summary.radviz <- function(object,...,n=6) {
-  cat('A Radviz object with',nrow(object$proj$data),'objects and',nrow(object$proj$layers[[1]]$data),'dimensions\n')
+  cat('A Radviz object with',nrow(object$proj$data),'objects and',length(springs(object)),'dimensions\n')
   print(head(object$proj$data,n))
   if(any(object$proj$data$rvalid)) {
     cat(sum(object$proj$data$rvalid),'point(s) could not be projected\n')
   }
-  das <- levels(object$proj$layers[[1]]$data$Channel)
+  das <- springs(object)
   if(length(das)>n) {
     das <- das[seq(1,n)]
     das <- c(das,'...')
@@ -41,7 +43,8 @@ head.radviz <- function(x,n=6,...) {
 #' @rdname summary.radviz
 #' @export
 dim.radviz <- function(x) {
-  dim(x$proj$data)
+  return(c(nrow(x$proj$data),
+           length(springs(x))))
 }
 
 #' @rdname summary.radviz
@@ -50,3 +53,9 @@ print.radviz <- function(x,...) {
   print(x$proj)
   return(invisible(x$proj$data))
 }
+
+#' @rdname summary.radviz
+#' @export
+springs <- function(x) {
+  return(levels(x$proj$layers[[1]]$data$Channel))
+}
\ No newline at end of file
