@@ -10,8 +10,8 @@
 #' @param color if color is not \code{NULL} and corresponds to one of the channels
 #'          in the \code{hexcols} slot of the Radviz object, cells will be colored
 #'          using colors in the \code{hexcols} slot
-#' @param label.color deprecated, see \code{\link{do.radviz}}
-#' @param label.size deprecated, see \code{\link{do.radviz}}
+#' @param label.color the color of springs for visualization
+#' @param label.size the size of labels
 #' @param mincnt deprecated, see \code{\link{stat_summary_hex}} instead
 #' @param style deprecated, see \code{\link{stat_summary_hex}} instead
 #' 
@@ -28,24 +28,31 @@ hexplot <- function(x,
                     main=NULL,
                     nbins=30,
                     color=NULL,
-                    label.color,
-                    label.size,
+                    label.color=NULL,
+                    label.size=NULL,
                     mincnt,
                     style) {
   ## check for deprecated arguments
-  if(!missing(label.color))
-    warning('label.color is a deprecated argument, use plot(x)+stat_summary_hex() and custom aes() to change plot.',call. = FALSE)
-  if(!missing(label.size))
-    warning('label.size is a deprecated argument, use plot(x)+stat_summary_hex() and custom aes() to change plot.',call. = FALSE)
   if(!missing(mincnt))
     warning('mincnt is a deprecated argument, use plot(x)+stat_summary_hex() and custom aes() to change plot.',call. = FALSE)
   if(!missing(style))
     warning('style is a deprecated argument, use plot(x)+stat_summary_hex() and custom aes() to change plot.',call. = FALSE)
+  
   ## plot
   p <- x$proj+
     ggtitle(main)+
     scale_fill_gradient(low='grey90',high='dodgerblue4')
   
+  if(!is.null(label.color) | !is.null(label.size)) {
+    if(is.null(label.size)) label.size <- NA
+    if(is.null(label.color)) label.color <- 'orangered4'
+    if(!is.numeric(label.size)) label.size <- as.numeric(label.size)
+    p$layers[[1]] <- geom_text(data = p$layers[[1]]$data,
+                               aes_string(x='X1',y='X2',label='Channel'),
+                               color=label.color,
+                               size=label.size)
+  }
+  
   if(is.null(color)) {
     slayer <- geom_hex(bins=nbins)
   } else {
